<?php
/**
 * @brief		Editor Extension: StickyNotes
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Sticky Notes
 * @since		31 Oct 2017
 */

namespace IPS\stickynotes\extensions\core\EditorLocations;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Editor Extension: StickyNotes
 */
class _StickyNotes
{
	public function canUseHtml( $member )
	{
		return NULL;
	}
	
	public function canAttach( $member, $field )
	{
		return NULL;
	}

	public function attachmentPermissionCheck( $member, $id1, $id2, $id3, $attachment )
	{
		return TRUE;
	}
	
	public function attachmentLookup( $id1, $id2, $id3 )
	{
		if( $id3 == 'stickynotes' )
		{
			return \IPS\stickynotes\StickyNotes::load( $id1 );
		}
		else
		{
			return \IPS\Member::load( $id2 );
		}
	}

	public function rebuildAttachmentImages( $offset, $max )
	{
		return $this->performRebuild( $offset, $max, array( 'IPS\Text\Parser', 'rebuildAttachmentUrls' ) );
	}

	public function rebuildContent( $offset, $max )
	{
		return $this->performRebuild( $offset, $max, array( 'IPS\Text\LegacyParser', 'parseStatic' ) );
	}

	protected $proxyUrl	= FALSE;

	public function rebuildImageProxy( $offset, $max, $proxyUrl = FALSE )
	{
		$this->proxyUrl = $proxyUrl;
		return $this->performRebuild( $offset, $max, 'parseImageProxy' );
	}

	protected $_lazyLoadStatus = null;

	public function rebuildLazyLoad( $offset, $max, $status=TRUE )
	{
		$this->_lazyLoadStatus = $status;

		return $this->performRebuild( $offset, $max, 'parseLazyLoad' );
	}

	protected function performRebuild( $offset, $max, $callback )
	{
		$did = 0;
		foreach( \IPS\Db::i()->select( '*', 'stickynotes_notes', null, 'id ASC', array( $offset, $max ) ) as $note )
		{
			$did++;
			try
			{
				if( $callback == 'parseImageProxy' )
				{
					$rebuilt = \IPS\Text\Parser::removeImageProxy( $note['note'] );
				}
				elseif( $callback == 'parseLazyLoad' )
				{
					$rebuilt = \IPS\Text\Parser::parseLazyLoad( $note['note'], $this->_lazyLoadStatus );
				}
				else
				{
					$rebuilt = $callback( $note['note'] );
				}
				
			}
			catch( \InvalidArgumentException $e )
			{
				if( $callback[1] == 'parseStatic' AND $e->getcode() == 103014 )
				{
					$rebuilt = preg_replace( "#\[/?([^\]]+?)\]#", '', $note['note'] );
				}
				else
				{
					throw $e;
				}
			}

			if( $rebuilt !== FALSE )
			{
				\IPS\Db::i()->update( 'stickynotes_notes', array( 'note' => $rebuilt ), array( 'id=?', $note['id'] ) );
			}
		}

		return $did;
	}

	public function contentCount()
	{
		return \IPS\Db::i()->select( 'COUNT(*) as count', 'stickynotes_notes', "note IS NOT NULL" )->first();
	}
}