<?php


namespace IPS\stickynotes\modules\admin\personalstickynotes;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * read
 */
class _read extends \IPS\Dispatcher\Controller
{	
	public static $csrfProtected = TRUE;

	protected function manage()
	{		
		/* Create the table */
		$table = new \IPS\Helpers\Table\Db( 'stickynotes_notes', \IPS\Http\Url::internal( 'app=stickynotes&module=personalstickynotes&controller=read' ) );
		$table->langPrefix = 'stickynotes__';

		/* Column stuff */
		$table->include = array( 'id', 'note', 'member_id', 'sender_id', 'anonymous', 'time_date', 'dismissed' );
		$table->exclude = array( 'id' );
		$table->mainColumn = 'note';
		$table->widths = array( 'id' => '5', 'note' => '50', 'member_id' => '10', 'sender_id' => '10','anonymous' => '8', 'time_date' => '10', 'dismissed' => '8' );
		
		/* Sort stuff */
		$table->sortBy = $table->sortBy ?: 'id';
		$table->sortDirection = $table->sortDirection ?: 'asc';
		
		/* Formatters */
		$table->parsers = array(
			'time_date'	=> function( $val, $row )
			{
				$date	= \IPS\DateTime::ts( $val );
				return $date->localeDate() . ' ' . $date->localeTime( FALSE ) ;
			},
			'member_id' => function( $val, $row )
			{
				$member_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['member_id'] . "'>$member_id->name</a>";
				
			},
			'sender_id' => function( $val, $row )
			{
				$sender_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['sender_id'] . "'>$sender_id->name</a>";
			},
			'note' => function( $val, $row )
			{
				$note = $val;
				return $note;
			},
			'dismissed' => function( $val, $row )
			{
				if( $val == 0)
				{
					$dismissed = '<center><i class="fa fa-times fa-lg" aria-hidden="true" style="color:red"></i></center>';
				}
				else if( $val == 1)
				{
				    $dismissed = '<center><i class="fa fa-check fa-lg" aria-hidden="true" style="color:green"></i></center>';
				}
				return $dismissed;
			},
			'anonymous' => function( $val, $row )
			{
				if( $val == NULL)
				{
					$anonymous = '<center><i class="fa fa-times fa-lg" aria-hidden="true" style="color:red"></i></center>';
				}
				else if( $val == 1)
				{
				    $anonymous = '<center><i class="fa fa-check fa-lg" aria-hidden="true" style="color:green"></i></center>';
				}
				return $anonymous;
			},
		);
		
		$table->rowButtons = function( $row ) {
			return array(
				'delete'	=> array(
				'title'	=> 'delete',
				'icon'	=> 'times-circle',
				'link'	=> \IPS\Http\Url::internal( "app=stickynotes&module=personalstickynotes&controller=read&do=deleteStickyNote&id={$row['id']}" )->csrf(),
				'data'	=> array( 'delete' => '' )
		    	),
			);
		};
		
		/* Buttons */
		\IPS\Output::i()->sidebar['actions']['add'] = array(
			'primary'	=> true,
			'icon'		=> 'trash',
			'title'		=> 'SN_MassDelete',
			'link'		=> \IPS\Http\Url::internal( 'app=stickynotes&module=personalstickynotes&controller=massdelete' ),
			'data'		=> array( 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('SN_MassDelete') )
		);		
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'SN_Read_Personal_Sticky_notes' );
		\IPS\Output::i()->output	= \IPS\Theme::i()->getTemplate( 'global', 'core' )->block( 'title', (string) $table );
	}
	
	public function deleteStickyNote()
	{
		\IPS\Session::i()->csrfCheck();
		\IPS\Request::i()->confirmedDelete();

		\IPS\Db::i()->delete( 'stickynotes_notes', array( 'id=?', \IPS\Request::i()->id ) );
		\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=stickynotes&module=personalstickynotes&controller=read' ) );
	}
}