<?php


namespace IPS\stickynotes\modules\front\stickynote;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * sendnote
 */
class _sendnote extends \IPS\Dispatcher\Controller
{
	protected function manage()
	{
		$stickyNote 		= NULL;
		$member 			= \IPS\Member::loggedIn();
		$memberData 		= \IPS\stickynotes\Members::getMemberData( $member->member_id );
		$messagesSentToday 	= \IPS\Db::i()->select( 'COUNT(*) AS count, MAX(time_date) AS max', 'stickynotes_notes', array( 'sender_id=? AND time_date>?', $member->member_id, \IPS\DateTime::create()->sub( new \DateInterval( 'P1D' ) )->getTimeStamp() ) )->first();

		if( !$member->member_id )
		{
			\IPS\Output::i()->error( 'no_module_permission_guest', 'StickyNotesGuest/1', 403, '' );
		}

		if( \IPS\Settings::i()->SN_PersonalGroups != 'all' AND !$member->inGroup( explode(',', \IPS\Settings::i()->SN_PersonalGroups ) ) )
		{
		    \IPS\Output::i()->error( 'no_permission_personal_member', 'StickyNotesGroups/1', 403, '' );
		}

		if( $memberData['blockpersonal'] )
		{
			\IPS\Output::i()->error( 'blocked_personal_member', 'StickyNotesBlocked/1', 403, '' );
		}

		$groupData = \IPS\Data\Store::i()->stickynotesGroups[ $member->member_group_id ];
		if( $groupData['g_sn_perday'] !== -1 )
		{
		    if( $messagesSentToday['count'] >= $groupData['g_sn_perday'] )
		    {
			    $next = \IPS\DateTime::ts( $messagesSentToday['max'] )->add( new \DateInterval( 'P1D' ) );
			    \IPS\Output::i()->error( $member->language()->addToStack( 'max_sticky_notes_day', FALSE, array( 'pluralize' => array( $groupData['g_sn_perday'] ) ) ), 'StickyNotesMAxNotes/2', 429, '', array( 'Retry-After' => $next->format('r') ) );
	        }
		}

		$form = new \IPS\Helpers\Form( 'stickynotes', 'SN_send' );
		$form->class = 'ipsForm_vertical ipsForm_fullWidth';
        $form->addTab('StickyNoteTab');
		$form->add( new \IPS\Helpers\Form\Member('StickyNoteMember', NULL, TRUE, array( ), function( $val )
        {
			if( !\IPS\Settings::i()->SN_AllowSelfSend )
		    {
	            if( $val == \IPS\Member::loggedIn() )
	            {
		            throw new \DomainException('SN_SendSelf');
	            }
		    }

			$memberData1 = \IPS\stickynotes\Members::getMemberData( $val->member_id );
		    if( $memberData1['blockreceiving'] == 1 )
			{
		        throw new \DomainException('SN_BlockReceiving');
	        }

			try
			{
			    $blocked = \IPS\Db::i()->select( 'ignore_list', 'stickynotes_ignore', array( 'member_id=?', $val->member_id ) )->first();
				if( \in_array( \IPS\Member::loggedIn()->member_id, explode( ',', ( $blocked ) ) ) )
			    {
				    throw new \DomainException('SN_Been_Blocked');
			    }
			}
			catch( \UnderflowException $e )
		    {
			    $blocked = array();
		    }
        }
		));
		$form->add( new \IPS\Helpers\Form\Editor( 'StickyNote', NULL, TRUE, array( 'app' => 'stickynotes', 'key' => 'StickyNotes', 'autoSaveKey' => '', 'attachIds' => $stickyNote ? array( $stickyNote->id ) : NULL ) ) );

		if( \IPS\Settings::i()->SN_PersonalAnon )
		{
			if( $groupData['g_sn_require_reply'] )
			{
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalUseAnon', FALSE, FALSE, array( 'togglesOff' => array( 'SN_PersonalRequireReply' ), 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalUseAnon_label' ) ) ) );
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalRequireReply', FALSE, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalRequireReply_label' ) ), NULL, NULL, NULL, 'SN_PersonalRequireReply' ) );
			}
			else
			{
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalUseAnon', FALSE, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalUseAnon_label' ) ) ) );	
			}
		}

		if( !\IPS\Settings::i()->SN_PersonalAnon AND $groupData['g_sn_require_reply'] )
		{
			$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalRequireReply', FALSE, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalRequireReply_label' ) ), NULL, NULL, NULL, 'SN_PersonalRequireReply' ) );
		}

		if( $values = $form->values() )
		{
			$sender_id = $member->member_id;
		    $group_id = $member->member_group_id;
		    $member_id = $values['StickyNoteMember']->member_id;
			$stickyNote = new \IPS\stickynotes\StickyNotes;
		    if( \IPS\Settings::i()->SN_PersonalAnon AND !$values['SN_PersonalUseAnon'] )
		    {
				$stickyNote->note = $values['StickyNote'];
				$stickyNote->sender_id = $sender_id;
				$stickyNote->member_id = $member_id;
				$stickyNote->time_date = time();
				$stickyNote->group_id = $group_id;
				$stickyNote->anonymous = NULL;
				$stickyNote->require_reply = isset( $values['SN_PersonalRequireReply'] ) ? $values['SN_PersonalRequireReply'] : 0;
				$stickyNote->save();
	        }
		    else if( \IPS\Settings::i()->SN_PersonalAnon AND $values['SN_PersonalUseAnon'] )
		    {
				$stickyNote->note = $values['StickyNote'];
				$stickyNote->sender_id = $sender_id;
				$stickyNote->member_id = $member_id;
				$stickyNote->time_date = time();
				$stickyNote->group_id = $group_id;
				$stickyNote->anonymous = 1;
				$stickyNote->require_reply = isset( $values['SN_PersonalRequireReply'] ) ? $values['SN_PersonalRequireReply'] : 0;
				$stickyNote->save();
	        }
		    else 
		    {
				$stickyNote->note = $values['StickyNote'];
				$stickyNote->sender_id = $sender_id;
				$stickyNote->member_id = $member_id;
				$stickyNote->time_date = time();
				$stickyNote->group_id = $group_id;
				$stickyNote->anonymous = NULL;
				$stickyNote->require_reply = isset( $values['SN_PersonalRequireReply'] ) ? $values['SN_PersonalRequireReply'] : 0;
				$stickyNote->save();
	        }
		    \IPS\File::claimAttachments( '', $stickyNote->id, $member_id, 'stickynotes' );
			\IPS\Output::i()->redirect( \IPS\Request::i()->referrer() ?: \IPS\Http\Url::internal( '' ), 'sticky_note_sent' );
		}

		\IPS\Session::i()->setLocation( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=sendnote', 'front' ), array(), 'loc_sending_note' );
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('sending_note');
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('form')->form( $form );
	}

	protected function restore()
	{
		$id  = \intval( \IPS\Request::i()->id );
		$stickyNote = \IPS\stickynotes\StickyNotes::load( $id );

		if( $stickyNote->dismissed == 0 )
		{
			\IPS\Output::i()->error( 'SN_Not_Dismissed_Yet', 'StickyNotesDismissed/1', 403, '' );
		}

		if( \IPS\Request::i()->what == 'resend' )
		{
			$stickyNote->dismissed = 0;
			$stickyNote->time_date = time();
			$stickyNote->save();
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=getmysnotes' ), 'Resent' );			
	    }
		else
		{
			$stickyNote->dismissed = 0;
			$stickyNote->save();
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes' ), 'Restored' );	
		}
	}

	protected function edit()
	{
		$id  		= \intval( \IPS\Request::i()->id );
		$member 	= \IPS\Member::loggedIn();
		$memberData = \IPS\stickynotes\Members::getMemberData( $member->member_id );
		$groupData  = \IPS\Data\Store::i()->stickynotesGroups[ $member->member_group_id ];

		try
		{
			$stickyNote = \IPS\stickynotes\StickyNotes::load( $id );
		}
		catch( \UnderflowException $ex )
		{
			\IPS\Output::i()->error( 'node_error', 'StickyNotesNode/8', 403, '' );
		}

		if( \IPS\Member::loggedIn()->member_id != $stickyNote->sender_id )
		{
			\IPS\Output::i()->error( 'SN_NotYourNote', 'StickyNotesNotYours/8', 403, '' );
		}

		if( \IPS\Settings::i()->SN_PersonalGroups != 'all' AND !$member->inGroup( explode(',', \IPS\Settings::i()->SN_PersonalGroups ) ) )
		{
		    \IPS\Output::i()->error( 'no_permission_personal_member', 'StickyNotesGroups/1', 403, '' );
		}

		if( $memberData['blockpersonal'] )
		{
			\IPS\Output::i()->error( 'blocked_personal_member', 'StickyNotesBlocked/1', 403, '' );
		}

		$form = new \IPS\Helpers\Form( 'stickynotes', 'SN_send' );
		$form->class = 'ipsForm_vertical ipsForm_fullWidth ipsForm_noLabels';
        $form->add( new \IPS\Helpers\Form\Editor( 'StickyNote', $stickyNote->note, TRUE, array( 'app' => 'stickynotes', 'key' => 'StickyNotes', 'autoSaveKey' => '', 'attachIds' => array( $stickyNote->id, $member->member_id, 'stickynotes'  ) ) ) );

		if( \IPS\Settings::i()->SN_PersonalAnon )
		{
			if( $groupData['g_sn_require_reply'] )
			{
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalUseAnon', $stickyNote->anonymous, FALSE, array( 'togglesOff' => array( 'SN_PersonalRequireReply' ), 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalUseAnon_label' ) ) ) );
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalRequireReply', $stickyNote->require_reply, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalRequireReply_label' ) ), NULL, NULL, NULL, 'SN_PersonalRequireReply' ) );
			}
			else
			{
				$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalUseAnon', $stickyNote->anonymous, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalUseAnon_label' ) ) ) );	
			}
		}

		if( !\IPS\Settings::i()->SN_PersonalAnon AND $groupData['g_sn_require_reply'] )
		{
			$form->add( new \IPS\Helpers\Form\YesNo( 'SN_PersonalRequireReply', $stickyNote->require_reply, FALSE, array( 'label' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_PersonalRequireReply_label' ) ), NULL, NULL, NULL, 'SN_PersonalRequireReply' ) );
		}

		if( $values = $form->values() )
		{
			$stickyNote->dismissed = 0;
	        $stickyNote->note = $values['StickyNote'];
			$stickyNote->time_date = time();
			$stickyNote->anonymous = $values['SN_PersonalUseAnon'];
			$stickyNote->require_reply = isset( $values['SN_PersonalRequireReply'] ) ? $values['SN_PersonalRequireReply'] : 0;
			$stickyNote->save();
			
			\IPS\File::claimAttachments( '', $stickyNote->id, $member->member_id, 'stickynotes' );
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=getmysnotes' ), 'Resent' );
		}
		
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('form')->form( $form );
	}
	
	protected function reply()
	{
		$member 	= \IPS\Member::loggedIn();
		$memberData = \IPS\stickynotes\Members::getMemberData( $member->member_id );

		if( !$member->member_id )
		{
			\IPS\Output::i()->error( 'no_module_permission_guest', 'StickyNotesGuest/1', 403, '' );
		}

		try
		{
		    $blocked = \IPS\Db::i()->select( 'ignore_list', 'stickynotes_ignore', array( 'member_id=?', $member->member_id ) )->first();
				
			if( \in_array( \IPS\Member::loggedIn()->member_id, explode( ',', ( $blocked ) ) ) )
		    {
				\IPS\Output::i()->error( 'SN_Been_Blocked', 'StickyNotesBlocked/1', 403, '' );
		    }
		}
		catch( \UnderflowException $e )
		{
		    $blocked = array();
		}

		$stickyNote = \IPS\stickynotes\StickyNotes::load( \IPS\Request::i()->id );

		$messagesSentToday = \IPS\Db::i()->select( 'COUNT(*) AS count, MAX(time_date) AS max', 'stickynotes_notes', array( 'sender_id=? AND time_date>?', $member->member_id, \IPS\DateTime::create()->sub( new \DateInterval( 'P1D' ) )->getTimeStamp() ) )->first();

		if( $stickyNote->anonymous == 1 )
		{
			\IPS\Output::i()->error( 'SN_Replying_To_Anonymous', 'StickyNotesAnonReply/1', 403, '' );
		}

		if( $stickyNote->member_id != $member->member_id )
		{
			\IPS\Output::i()->error( 'SN_Replying_To_Others', 'StickyNotesNotYours/1', 403, '' );
		}

		if( \IPS\Settings::i()->SN_PersonalGroups != 'all' AND !$member->inGroup( explode(',', \IPS\Settings::i()->SN_PersonalGroups ) ) )
		{
		    \IPS\Output::i()->error( 'no_permission_personal_member', 'StickyNotesGroups/1', 403, '' );
		}

		if( $memberData['blockpersonal'] )
		{
			\IPS\Output::i()->error( 'blocked_personal_member', 'StickyNotesBlocked/1', 403, '' );
		}

		$groupData = \IPS\Data\Store::i()->stickynotesGroups[ $member->member_group_id ];
		if( $groupData['g_sn_perday'] !== -1 )
		{
		    if( $messagesSentToday['count'] >= $groupData['g_sn_perday'] )
		    {
			    $next = \IPS\DateTime::ts( $messagesSentToday['max'] )->add( new \DateInterval( 'P1D' ) );
			    \IPS\Output::i()->error( $member->language()->addToStack( 'max_sticky_notes_day', FALSE, array( 'pluralize' => array( $groupData['g_sn_perday'] ) ) ), 'StickyNotesMAxNotes/3', 429, '', array( 'Retry-After' => $next->format('r') ) );
	        }
		}

		$form = new \IPS\Helpers\Form( 'stickynotes', 'SN_send' );
		$form->class = 'ipsForm_vertical ipsForm_fullWidth ipsForm_noLabels';
        $form->addTab('StickyNoteTab');
		$form->add( new \IPS\Helpers\Form\Editor( 'StickyNote', NULL, TRUE, array( 'app' => 'stickynotes', 'key' => 'StickyNotes', 'autoSaveKey' => '', 'attachIds' => NULL ) ) );

		if( $values = $form->values() )
		{
			$sender_id = $member->member_id;
		    $group_id = $member->member_group_id;

			$repiedNote = new \IPS\stickynotes\StickyNotes;
			$repiedNote->note = $values['StickyNote'];
			$repiedNote->sender_id = $member->member_id;
			$repiedNote->member_id = $stickyNote->sender_id;
			$repiedNote->time_date = time();
			$repiedNote->group_id = $group_id;
			$repiedNote->anonymous = NULL;
			$repiedNote->save();

			$stickyNote->dismissed = 1;
			$stickyNote->save();
			\IPS\File::claimAttachments( '', $repiedNote->id, $member->member_id, 'stickynotes' );
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( '' ), 'sticky_note_sent' );
		}

		\IPS\Session::i()->setLocation( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=sendnote', 'front' ), array(), 'loc_sending_note' );
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('sending_note');
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('form')->form( $form );
	}
}