<?php


namespace IPS\stickynotes\modules\front\stickynote;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * viewnotes
 */
class _viewnotes extends \IPS\Dispatcher\Controller
{
	protected function manage()
	{
		if( !\IPS\Member::loggedIn()->member_id )
		{
			\IPS\Output::i()->error( 'no_module_permission_guest', 'StickyNotesGuest/1', 403, '' );
		}
		
		$member_id = \IPS\Member::loggedIn()->member_id;
		
		/* Build Table */
		$table = new \IPS\Helpers\Table\Db( 'stickynotes_notes', \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes' ) );
		$table->include = array( 'time_date', 'sender_id', 'note', 'id', 'anonymous' );
		$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('tables'), 'rows' );
		$table->joins = array();
		$table->limit = 10;
		$table->where[] = array( 'member_id=?', $member_id );
		$table->langPrefix = 'snall__';
		/* Sort */
		$table->sortOptions = array( 'time_date' => 'time_date' );
		$table->sortBy = $table->sortBy ?: 'time_date';
		if( $table->sortBy === 'time_date' )
		{
			$table->sortDirection = 'DESC';
		}
		$table->advancedSearch = array(
			'sender_id'		=> \IPS\Helpers\Table\SEARCH_MEMBER,
			'time_date'		=> \IPS\Helpers\Table\SEARCH_DATE_RANGE,
		);
		
		/* Location for online list */
		\IPS\Session::i()->setLocation( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes', 'front' ), array(), 'loc_reading_notes' );
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('SN_my_notes');
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack('SN_my_notes') );
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('tables')->template( (string) $table, \IPS\Db::i()->select( 'SUM(id)', 'stickynotes_notes', array( 'member_id=?', \IPS\Member::loggedIn()->member_id ) )->first(), \IPS\Db::i()->select( 'COUNT(*)', 'stickynotes_notes', array( 'member_id=?', \IPS\Member::loggedIn()->member_id ) )->first() );
	}
	
	protected function getmysnotes()
	{
		if( !\IPS\Member::loggedIn()->member_id )
		{
			\IPS\Output::i()->error( 'no_module_permission_guest', 'StickyNotesGuest/1', 403, '' );
		}
		
		$member_id = \IPS\Member::loggedIn()->member_id;
		
		/* Build Table */
		$table = new \IPS\Helpers\Table\Db( 'stickynotes_notes', \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=getmysnotes' ) );
		$table->include = array( 'time_date', 'sender_id', 'note', 'id', 'anonymous', 'member_id', 'dismissed', 'require_reply' );
		$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('tables'), 'Srows' );
		$table->joins = array();
		$table->limit = 10;
		$table->where[] = array( 'sender_id=?', $member_id );
		$table->langPrefix = 'snall__';
		/* Sort */
		$table->sortOptions = array( 'time_date' => 'time_date' );
		$table->sortBy = $table->sortBy ?: 'time_date';
		if( $table->sortBy === 'time_date' )
		{
			$table->sortDirection = 'DESC';
		}
		$table->advancedSearch = array(
			'member_id'		    => \IPS\Helpers\Table\SEARCH_MEMBER,
			'time_date'		=> \IPS\Helpers\Table\SEARCH_DATE_RANGE,
		);
		
		/* Location for online list */
		\IPS\Session::i()->setLocation( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=getmysnotes', 'front' ), array(), 'loc_reading_snotes' );
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('SN_my_snotes');
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack('SN_my_snotes') );
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('tables')->Stemplate( (string) $table, \IPS\Db::i()->select( 'SUM(id)', 'stickynotes_notes', array( 'sender_id=?', \IPS\Member::loggedIn()->member_id ) )->first(), \IPS\Db::i()->select( 'COUNT(*)', 'stickynotes_notes', array( 'sender_id=?', \IPS\Member::loggedIn()->member_id ) )->first() );
	}
	
	protected function logs()
	{
		
		if( !\IPS\Member::loggedIn()->member_id )
		{
			\IPS\Output::i()->error( 'no_module_permission_guest', 'StickyNotesGuest/1', 403, '' );
		}
		
		$sid  = \intval( \IPS\Request::i()->sid );
		$member_id = \IPS\Member::loggedIn()->member_id;
		
		/* Build Table */
		$table = new \IPS\Helpers\Table\Db( 'stickynotes_notes', \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=logs' ) );
		$table->include = array( 'time_date', 'sender_id', 'note', 'id', 'anonymous', 'member_id', 'dismissed', 'require_reply' );
		$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('tables'), 'lrows' );
		$table->joins = array();
		$table->limit = 10;
		$table->where = array( array( 'sender_id=? AND member_id=? AND anonymous=? OR member_id=? AND sender_id=? AND anonymous=?', $sid, $member_id, NULL, $sid, $member_id, NULL ) );
		$table->langPrefix = 'snall__';
		/* Sort */
		$table->sortOptions = array( 'time_date' => 'time_date' );
		$table->sortBy = $table->sortBy ?: 'time_date';
		if( $table->sortBy === 'time_date' )
		{
			$table->sortDirection = 'DESC';
		}
		$table->advancedSearch = array(
			'sender_id'		    => \IPS\Helpers\Table\SEARCH_MEMBER,
			'time_date'		=> \IPS\Helpers\Table\SEARCH_DATE_RANGE,
		);
		
		/* Location for online list */
		\IPS\Session::i()->setLocation( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynote&controller=viewnotes&do=logs', 'front' ), array(), 'loc_reading_notes' );
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('SN_my_notes');
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack('SN_my_notes') );
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('tables')->ltemplate( (string) $table, \IPS\Db::i()->select( 'SUM(id)', 'stickynotes_notes', array( 'member_id=?', \IPS\Member::loggedIn()->member_id ) )->first(), \IPS\Db::i()->select( 'COUNT(*)', 'stickynotes_notes', array( 'member_id=?', \IPS\Member::loggedIn()->member_id ) )->first() );
	}
}