<?php

namespace IPS\stickynotes;

class _GlobalNote extends \IPS\Node\Model
{
    protected static $multitons;
    protected static $defaultValues = null;
    public static $databaseTable = 'stickynotes_global_notes';
    public static $databasePrefix = '';
    public static $databaseColumnOrder = 'level';
	protected static $databaseIdFields = ['id', 'title' ];
	public static $nodeTitle = 'stickynotes_global_notes';
    public static $titleSearchPrefix = 'stickynotes_global_notes_';
	
    protected function get__title()
    {
       return $this->title;
    }
	
	protected function get__enabled()
    {
        return $this->active;
    }
    
    protected function set__enabled( $enabled )
    {
        $this->active = $enabled;
    }
    
    public function form( &$form )
    {
		$member = \IPS\Member::loggedIn();
		$GlobalStickyNote = NULL;
		if( \IPS\Request::i()->id == TRUE )
		{
			$colour = $this->colour;
			$groups = $this->show_to;
			$time = $this->show_until;
			$where = $this->where;
			$attach = array( $this->id, $member->member_id, 'globalstickynotes' );
		}
		else
		{
			$colour = "EAE672";
			$groups = "all";
			$time = -1;
			$where = "all";
			$attach = NULL;
		}
		
        $form = new \IPS\Helpers\Form;
		$form->add( new \IPS\Helpers\Form\Text( 'SN_Title', $this->title, TRUE, array( ) ) );
		$tags = \IPS\stickynotes\GlobalNote::getTags();
        $form->add( new \IPS\Helpers\Form\Editor( 'SN_Content', $this->note, TRUE, array( 'app' => 'stickynotes', 'key' => 'StickyNotes', 'autoSaveKey' => '', 'attachIds' => $attach, 'tags' => $tags ), NULL, NULL, NULL, 'SN_Content' ) );
        $form->add( new \IPS\Helpers\Form\Color( 'SN_Colour', $colour, TRUE, array( 'app' => 'core', 'key' => 'Admin', 'autoSaveKey' => 'SN_Colour' ), NULL, NULL, NULL, 'SN_Colour' ) );
        $form->add( new \IPS\Helpers\Form\Select( 'SN_Position', $this->position, TRUE, array( 'app' => 'core', 'key' => 'Admin', 'autoSaveKey' => 'SN_Position', 'options' => array( 0 => 'Top Left', 1 => 'Top Right', 2 => 'Top Center', 3 => 'Bottom Left', 4 => 'Bottom Right', 5 => 'Bottom Center', 6 => 'Middle Left', 7 => 'Middle Right', 8 => 'Middle Center' ), 'multiple' => FALSE ) , NULL, NULL, NULL, 'SN_Position') );
        $form->add( new \IPS\Helpers\Form\Member( 'SN_Signature', $this->signature ? array_map( array( 'IPS\Member', 'load' ), explode( "\n", $this->signature ) ) : NULL, FALSE, array( 'max' => 1 ), NULL, NULL, NULL, 'SN_Signature' ) );
        $form->add( new \IPS\Helpers\Form\Select( 'SN_Groups', ( $groups == 'all' ) ? 'all' : explode( ',', $this->show_to ), TRUE, array( 'options' => \IPS\Member\Group::groups(), 'parse' => 'normal', 'multiple' => true, 'unlimited' => 'all', 'unlimitedLang' => 'all_groups' ), NULL, NULL, NULL, 'SN_Groups' ) );
        $form->add( new \IPS\Helpers\Form\Date( 'SN_ShowUntil', $time, TRUE, array( 'time' => TRUE, 'unlimited' => -1, 'unlimitedLang' => 'SN_UntilTheyDismiss' ), NULL, \IPS\Member::loggedIn()->language()->addToStack('until'), NULL, 'SN_ShowUntil' ) );
		$sql = \IPS\Db::i()->select( '*', 'core_applications', array( 'app_protected=? AND app_enabled=?', 0, 1 ) );
		foreach( $sql as $k => $v )
        {
			$appName = \IPS\Application::load( $v[ 'app_id' ], 'app_id' )->_title;
            $f[ $v[ 'app_directory' ] ] = $appName;
        }
		$form->add( new \IPS\Helpers\Form\Select( 'SN_Where', $where, TRUE, array( 'options' => $f, 'unlimited' => 'all', 'unlimitedLang' => "Everywhere" ), NULL, NULL, NULL, 'SN_Where' ) );
		
        if( $values = $form->values(TRUE) )
	    {
			if( \IPS\Request::i()->id == TRUE )
			{
				$id  = \intval( \IPS\Request::i()->id );
				$GlobalStickyNote = \IPS\stickynotes\GlobalNote::load( $id );
			}
			else
			{
				$GlobalStickyNote = new \IPS\stickynotes\GlobalNote;
				$GlobalStickyNote->level = 0;
			}
			
			$GlobalStickyNote->active = 1;
			$GlobalStickyNote->title = $values['SN_Title'];
			$GlobalStickyNote->note = $values['SN_Content'];
			$GlobalStickyNote->colour = $values['SN_Colour'];
			$GlobalStickyNote->position = $values['SN_Position'];
			$GlobalStickyNote->signature = $values['SN_Signature'];
			$GlobalStickyNote->show_to = $values['SN_Groups'];
			$GlobalStickyNote->show_until = $values['SN_ShowUntil'];
			$GlobalStickyNote->where = $values['SN_Where'];
			$GlobalStickyNote->save();
			\IPS\File::claimAttachments( '', $GlobalStickyNote->id, $member->member_id, 'globalstickynotes' );
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=stickynotes&module=stickynotes&controller=globalnotes' ), 'saved' );
		}
		
	}
	
    public function getButtons( $url, $subnode = false )
    {
        $buttons = parent::getButtons( $url, $subnode );
        $buttons[ 'links' ] = [
            'icon'  => 'refresh',
            'title' => 'Re-Issue',
            'link'  => \IPS\Http\Url::internal( "app=stickynotes&module=stickynotes&controller=globalnotes&id={$this->_id}&do=refresh" )->csrf(),
            'data'  => [ 'ipsDialog' => '', 'ipsDialog-forceReload' => 'true', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack( 'SN_reissue' ) ]
        ];
        
        return $buttons;
    }
    
    public function canCopy()
    {
        return false;
    }
    
    public function delete()
    {
		\IPS\Db::i()->delete( 'stickynotes_dismissed', array( 'note_id=?', $this->id ) );
        parent::delete();
    }
	
	public static function search( $column, $query, $order=NULL, $where=array() )
	{
		if( $column === '_title' )
		{
			$column	= 'title';
		}

		if( $order == '_title' )
		{
			$order	= 'title';
		}

		return parent::search( $column, $query, $order, $where );
	} 
	
	public static function getTags()
	{
		$tags = array(
		    '%board_name%'	 	 	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_board_name'),
		    '%member_name%'	 	 	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_name'),
			'%member_tag%'	 	 	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_tag'),
			'%member_profile%'	 	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_profile'),
			'%member_joined%'	 	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_joined'),
			'%member_days_with_us%'	 	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_days_with_us'),
			'%member_posts%'	 		=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_posts'),
			'%member_posts_per_day%'	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_posts_per_day'),
			'%member_topics%'	 		=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_topics'),
			'%member_topics_per_day%'	=> \IPS\Member::loggedIn()->language()->addToStack('stickynotes_tag_member_topics_per_day'),
		);
		return $tags;
	} 
	
	public static function returnTagValues( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		
		$now = time();
		$joined = strtotime( $member->joined );
		$days = floor( ( $now - $joined ) / ( 60*60*24 ) );
		$topicCount = (int) \IPS\Db::i()->select( 'COUNT(*)', 'forums_topics', array( 'starter_id=?', $member->member_id ) )->first();
		
		$tags['%board_name%']				= \IPS\Settings::i()->board_name;
	    $tags['%member_name%']				= $member->name;
		$tags['%member_tag%']				= "<a class='ipsCursor_pointer' data-ipshover=\"\" data-ipshover-target='{$member->url()->setQueryString('do', 'hovercard')}' data-mentionid=\"{$member->member_id}\" href=\"{$member->url()}\" contenteditable=\"false\">@{$member->name}</a>";
		$tags['%member_profile%']			= "<a href=".$member->url().">".\IPS\Member::loggedIn()->language()->addToStack('sticky_notes_view_member')."</a>";
		$tags['%member_joined%']			= \IPS\DateTime::ts( $joined )->format( 'F j, Y' );
		$tags['%member_days_with_us%']		= number_format( $days );
		$tags['%member_posts%']				= number_format( $member->member_posts );
		if( $member->member_id  AND $days > 0 )
		{
			try
			{
				$tags['%member_posts_per_day%']		= number_format( $member->member_posts / $days, 2 );
				$tags['%member_topics_per_day%']	= number_format( $topicCount / $days, 2 );
			}
			catch( \Exception $e )
			{
				$tags['%member_posts_per_day%']		= 0;
				$tags['%member_topics_per_day%']	= 0;
			}
		}
		else
		{
			$tags['%member_posts_per_day%']		= 0;
			$tags['%member_topics_per_day%']	= 0;
		}
		$tags['%member_topics%']			= $topicCount;
		return $tags;
	}
	
	public function showNote( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		if( !$this->beenDismissed() AND $this->showOnApp() AND !$this->timePast() AND $this->showToGroup() AND $this->active )
		{
			return TRUE;
		}
		return FALSE;
	}
	
	public function beenDismissed( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		$count = \IPS\Db::i()->select( 'COUNT(*)', 'stickynotes_dismissed', array( 'member_id=? AND dismissed=? AND note_id=?', $member->member_id, 1, $this->id ) )->first();
		if( $count or isset( \IPS\Request::i()->cookie["SN_dismissed".$this->id.""] ) )
		{
			return TRUE; 
		}
		return FALSE;
	}
	
	public function showOnApp()
	{
		if( $this->where == 'all' OR \IPS\Request::i()->app == $this->where )
		{
			return TRUE;
		}
		return FALSE;
	}
	
	public function timePast()
	{
		if( time() > $this->show_until AND $this->show_until != -1  )
		{
			return TRUE;
		}
		return FALSE;
	}
	
	public function showToGroup( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		if(	$this->show_to == 'all' or $member->inGroup( explode(',', $this->show_to ) ) )
		{
			return TRUE;
		}
		return FALSE;
	}
	
	public function getSender()
	{
		return \IPS\Member::load( $this->signature );
	}
	
	public function dismissURL( $member=NULL )
	{
		return \IPS\Http\Url::internal( "app=stickynotes&module=dismiss&controller=stickynotes&do=dismissStickyNote&id=".$this->id."", 'front', 'dismiss_note' );
	}
}