<?php
/**
 * @brief		mostreceivednotes Widget
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	stickynotes
 * @since		02 Nov 2017
 */

namespace IPS\stickynotes\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * mostreceivednotes Widget
 */
class _mostreceivednotes extends \IPS\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'mostreceivednotes';
	
	/**
	 * @brief	App
	 */
	public $app = 'stickynotes';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
	
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
		$this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', $this->app, 'front' ), $this->key ) );
		parent::init();
	}
	
	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
 		$form = parent::configuration( $form );

 		/* Number to show */
		$form->add( new \IPS\Helpers\Form\Number( 'SN_widget_show_amount', isset( $this->configuration['SN_widget_show_amount'] ) ? $this->configuration['SN_widget_show_amount'] : 5, TRUE ) );

 		// $$form->add( new \IPS\Helpers\Form\XXXX( .... ) );
 		return $form;
 	} 
 	
 	 /**
 	 * Ran before saving widget configuration
 	 *
 	 * @param	array	$values	Values from form
 	 * @return	array
 	 */
 	public function preConfig( $values )
 	{
 		return $values;
 	}

	/**
	 * Render a widget
	 *
	 * @return	string
	 */
	public function render()
	{
		$limit = isset( $this->configuration['SN_widget_show_amount'] ) ? $this->configuration['SN_widget_show_amount'] : 5;
		$mostReceived = array();
		foreach ( \IPS\Db::i()->select( array( 'member_id', 'time_date' ), 'stickynotes_notes', array( 'anonymous IS NULL OR anonymous=?', 0 ) ) as $rep )
		{
			if( !isset( $mostReceived[ $rep['member_id'] ] ) )
			{
				$mostReceived[ $rep['member_id'] ] = 1;
			}
			else
			{
				$mostReceived[ $rep['member_id'] ] += 1;
			}
		}
		arsort( $mostReceived );
		$mostReceived = \array_slice( $mostReceived, 0, $limit, TRUE );
		
		/* Load their data */	
		foreach ( \IPS\Db::i()->select( '*', 'core_members', \IPS\Db::i()->in( 'member_id', array_keys( $mostReceived ) ) ) as $member )
		{
			\IPS\Member::constructFromData( $member );
		}
		
		return $this->output( $mostReceived );
	}
}